@@ -1,7 +1,8 @@
 import imp
 import sys
 
-from eventlet.support import six
+import eventlet
+import six
 
 
 __all__ = ['inject', 'import_patched', 'monkey_patch', 'is_monkey_patched']
@@ -89,6 +90,12 @@ def inject(module_name, new_globals, *additional_modules):
     # Remove the old module from sys.modules and reimport it while
     # the specified modules are in place
     sys.modules.pop(module_name, None)
+    # Also remove sub modules and reimport. Use copy the keys to list
+    # because of the pop operations will change the content of sys.modules
+    # within th loop
+    for imported_module_name in list(sys.modules.keys()):
+        if imported_module_name.startswith(module_name + '.'):
+            sys.modules.pop(imported_module_name, None)
     try:
         module = __import__(module_name, {}, {}, module_name.split('.')[:-1])
 
@@ -222,9 +229,30 @@ def monkey_patch(**on):
 
     It's safe to call monkey_patch multiple times.
     """
+
+    # Workaround for import cycle observed as following in monotonic
+    # RuntimeError: no suitable implementation for this system
+    # see https://github.com/eventlet/eventlet/issues/401#issuecomment-325015989
+    #
+    # Make sure the hub is completely imported before any
+    # monkey-patching, or we risk recursion if the process of importing
+    # the hub calls into monkey-patched modules.
+    eventlet.hubs.get_hub()
+
     accepted_args = set(('os', 'select', 'socket',
-                         'thread', 'time', 'psycopg', 'MySQLdb', '__builtin__'))
+                         'thread', 'time', 'psycopg', 'MySQLdb',
+                         'builtins', 'subprocess'))
+    # To make sure only one of them is passed here
+    assert not ('__builtin__' in on and 'builtins' in on)
+    try:
+        b = on.pop('__builtin__')
+    except KeyError:
+        pass
+    else:
+        on['builtins'] = b
+
     default_on = on.pop("all", None)
+
     for k in six.iterkeys(on):
         if k not in accepted_args:
             raise TypeError("monkey_patch() got an unexpected "
@@ -235,32 +263,28 @@ def monkey_patch(**on):
         if modname == 'MySQLdb':
             # MySQLdb is only on when explicitly patched for the moment
             on.setdefault(modname, False)
-        if modname == '__builtin__':
+        if modname == 'builtins':
             on.setdefault(modname, False)
         on.setdefault(modname, default_on)
 
-    modules_to_patch = []
-    if on['os'] and not already_patched.get('os'):
-        modules_to_patch += _green_os_modules()
-        already_patched['os'] = True
-    if on['select'] and not already_patched.get('select'):
-        modules_to_patch += _green_select_modules()
-        already_patched['select'] = True
-    if on['socket'] and not already_patched.get('socket'):
-        modules_to_patch += _green_socket_modules()
-        already_patched['socket'] = True
     if on['thread'] and not already_patched.get('thread'):
-        modules_to_patch += _green_thread_modules()
-        already_patched['thread'] = True
-    if on['time'] and not already_patched.get('time'):
-        modules_to_patch += _green_time_modules()
-        already_patched['time'] = True
-    if on.get('MySQLdb') and not already_patched.get('MySQLdb'):
-        modules_to_patch += _green_MySQLdb()
-        already_patched['MySQLdb'] = True
-    if on.get('__builtin__') and not already_patched.get('__builtin__'):
-        modules_to_patch += _green_builtins()
-        already_patched['__builtin__'] = True
+        _green_existing_locks()
+
+    modules_to_patch = []
+    for name, modules_function in [
+        ('os', _green_os_modules),
+        ('select', _green_select_modules),
+        ('socket', _green_socket_modules),
+        ('thread', _green_thread_modules),
+        ('time', _green_time_modules),
+        ('MySQLdb', _green_MySQLdb),
+        ('builtins', _green_builtins),
+        ('subprocess', _green_subprocess_modules),
+    ]:
+        if on[name] and not already_patched.get(name):
+            modules_to_patch += modules_function()
+            already_patched[name] = True
+
     if on['psycopg'] and not already_patched.get('psycopg'):
         try:
             from eventlet.support import psycopg2_patcher
@@ -284,6 +308,10 @@ def monkey_patch(**on):
                 patched_attr = getattr(mod, attr_name, None)
                 if patched_attr is not None:
                     setattr(orig_mod, attr_name, patched_attr)
+            deleted = getattr(mod, '__deleted__', [])
+            for attr_name in deleted:
+                if hasattr(orig_mod, attr_name):
+                    delattr(orig_mod, attr_name)
     finally:
         imp.release_lock()
 
@@ -293,6 +321,13 @@ def monkey_patch(**on):
         # importlib must use real thread locks, not eventlet.Semaphore
         importlib._bootstrap._thread = thread
 
+        # Issue #185: Since Python 3.3, threading.RLock is implemented in C and
+        # so call a C function to get the thread identifier, instead of calling
+        # threading.get_ident(). Force the Python implementation of RLock which
+        # calls threading.get_ident() and so is compatible with eventlet.
+        import threading
+        threading.RLock = threading._PyRLock
+
 
 def is_monkey_patched(module):
     """Returns True if the given module is monkeypatched currently, False if
@@ -306,6 +341,64 @@ def is_monkey_patched(module):
         getattr(module, '__name__', None) in already_patched
 
 
+def _green_existing_locks():
+    """Make locks created before monkey-patching safe.
+
+    RLocks rely on a Lock and on Python 2, if an unpatched Lock blocks, it
+    blocks the native thread. We need to replace these with green Locks.
+
+    This was originally noticed in the stdlib logging module."""
+    import gc
+    import threading
+    import eventlet.green.thread
+    lock_type = type(threading.Lock())
+    rlock_type = type(threading.RLock())
+    if sys.version_info[0] >= 3:
+        pyrlock_type = type(threading._PyRLock())
+    # We're monkey-patching so there can't be any greenlets yet, ergo our thread
+    # ID is the only valid owner possible.
+    tid = eventlet.green.thread.get_ident()
+    for obj in gc.get_objects():
+        if isinstance(obj, rlock_type):
+            if (sys.version_info[0] == 2 and
+                    isinstance(obj._RLock__block, lock_type)):
+                _fix_py2_rlock(obj, tid)
+            elif (sys.version_info[0] >= 3 and
+                    not isinstance(obj, pyrlock_type)):
+                _fix_py3_rlock(obj)
+
+
+def _fix_py2_rlock(rlock, tid):
+    import eventlet.green.threading
+    old = rlock._RLock__block
+    new = eventlet.green.threading.Lock()
+    rlock._RLock__block = new
+    if old.locked():
+        new.acquire()
+        rlock._RLock__owner = tid
+
+
+def _fix_py3_rlock(old):
+    import gc
+    import threading
+    new = threading._PyRLock()
+    while old._is_owned():
+        old.release()
+        new.acquire()
+    if old._is_owned():
+        new.acquire()
+    gc.collect()
+    for ref in gc.get_referrers(old):
+        try:
+            ref_vars = vars(ref)
+        except TypeError:
+            pass
+        else:
+            for k, v in ref_vars.items():
+                if v == old:
+                    setattr(ref, k, new)
+
+
 def _green_os_modules():
     from eventlet.green import os
     return [('os', os)]
@@ -313,7 +406,13 @@ def _green_os_modules():
 
 def _green_select_modules():
     from eventlet.green import select
-    return [('select', select)]
+    modules = [('select', select)]
+
+    if sys.version_info >= (3, 4):
+        from eventlet.green import selectors
+        modules.append(('selectors', selectors))
+
+    return modules
 
 
 def _green_socket_modules():
@@ -325,6 +424,11 @@ def _green_socket_modules():
         return [('socket', socket)]
 
 
+def _green_subprocess_modules():
+    from eventlet.green import subprocess
+    return [('subprocess', subprocess)]
+
+
 def _green_thread_modules():
     from eventlet.green import Queue
     from eventlet.green import thread
@@ -351,7 +455,7 @@ def _green_MySQLdb():
 def _green_builtins():
     try:
         from eventlet.green import builtin
-        return [('__builtin__', builtin)]
+        return [('__builtin__' if six.PY2 else 'builtins', builtin)]
     except ImportError:
         return []
 
