@@ -3,7 +3,7 @@ import shutil
 import sys
 import tempfile
 
-from eventlet.support import six
+import six
 import tests
 
 
@@ -87,6 +87,10 @@ def test_import_patched_defaults():
     tests.run_isolated('patcher_import_patched_defaults.py')
 
 
+def test_import_patched_handles_sub_modules():
+    tests.run_isolated('test_sub_module_in_import_patched/test.py')
+
+
 class MonkeyPatch(ProcessBase):
     def test_patched_modules(self):
         new_mod = """
@@ -209,7 +213,7 @@ def test_monkey_patch_threading():
     tickcount = [0]
 
     def tick():
-        from eventlet.support import six
+        import six
         for i in six.moves.range(1000):
             tickcount[0] += 1
             eventlet.sleep()
@@ -312,23 +316,6 @@ print(len(_threading._active))
         assert lines[1] == '1', lines
         assert lines[2] == '1', lines
 
-    def test_threading(self):
-        new_mod = """import eventlet
-eventlet.monkey_patch()
-import threading
-def test():
-    print(repr(threading.currentThread()))
-t = threading.Thread(target=test)
-t.start()
-t.join()
-print(len(threading._active))
-"""
-        self.write_to_tempfile("newmod", new_mod)
-        output, lines = self.launch_subprocess('newmod.py')
-        self.assertEqual(len(lines), 3, "\n".join(lines))
-        assert lines[0].startswith('<_MainThread'), lines[0]
-        self.assertEqual(lines[1], "1", lines[1])
-
     def test_tpool(self):
         new_mod = """import eventlet
 eventlet.monkey_patch()
@@ -493,6 +480,11 @@ def test_patcher_existing_locks_locked():
     tests.run_isolated('patcher_existing_locks_locked.py')
 
 
+@tests.skip_if_CRLock_exist
+def test_patcher_existing_locks_unlocked():
+    tests.run_isolated('patcher_existing_locks_unlocked.py')
+
+
 def test_importlib_lock():
     tests.run_isolated('patcher_importlib_lock.py')
 
@@ -515,3 +507,7 @@ def test_blocking_select_methods_are_deleted():
 
 def test_regular_file_readall():
     tests.run_isolated('regular_file_readall.py')
+
+
+def test_threading_current():
+    tests.run_isolated('patcher_threading_current.py')
