@@ -6,7 +6,8 @@ from eventlet.green import thread
 from eventlet.green import threading
 from eventlet.green import time
 
-patcher.inject("test.test_asynchat",
+patcher.inject(
+    "test.test_asynchat",
     globals(),
     ('asyncore', asyncore),
     ('asynchat', asynchat),
@@ -14,6 +15,6 @@ patcher.inject("test.test_asynchat",
     ('thread', thread),
     ('threading', threading),
     ('time', time))
-    
+
 if __name__ == "__main__":
-    test_main()
\ No newline at end of file
+    test_main()
