@@ -2,10 +2,11 @@ from eventlet import patcher
 from eventlet.green import httplib
 from eventlet.green import socket
 
-patcher.inject('test.test_httplib',
+patcher.inject(
+    'test.test_httplib',
     globals(),
     ('httplib', httplib),
     ('socket', socket))
-    
+
 if __name__ == "__main__":
-    test_main()
\ No newline at end of file
+    test_main()
