@@ -1,12 +1,11 @@
 from eventlet import patcher
 from eventlet.green import select
 
-patcher.inject('test.test_select',
+
+patcher.inject(
+    'test.test_select',
     globals(),
     ('select', select))
-    
+
 if __name__ == "__main__":
-    try:
-        test_main()
-    except NameError:
-        pass # 2.5
\ No newline at end of file
+    test_main()
