@@ -21,7 +21,7 @@ import time
 
 import eventlet
 from eventlet import tpool
-from eventlet.support import six
+import six
 import tests
 
 
@@ -367,3 +367,7 @@ class TpoolLongTests(tests.LimitedTestCase):
 
 def test_isolate_from_socket_default_timeout():
     tests.run_isolated('tpool_isolate_socket_default_timeout.py', timeout=1)
+
+
+def test_exception_leak():
+    tests.run_isolated('tpool_exception_leak.py')
